@@ -3,7 +3,7 @@ A grok.EditForm is a special grok.View that renders an edit form.
 
   >>> getRootFolder()["manfred"] = Mammoth()
 
-  >>> from zope.testbrowser.testing import Browser
+  >>> from zope.app.wsgi.testlayer import Browser
   >>> browser = Browser()
   >>> browser.handleErrors = False
   >>> browser.open("http://localhost/manfred/@@edit")
